@@ -2,16 +2,18 @@
  * jQuery JavaScript Library v@VERSION
  * http://jquery.com/
  *
- * Copyright 2010, John Resig
+ * Copyright 2011, John Resig
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
  * Includes Sizzle.js
  * http://sizzlejs.com/
- * Copyright 2010, The Dojo Foundation
+ * Copyright 2011, The Dojo Foundation
  * Released under the MIT, BSD, and GPL Licenses.
  *
- * Date: 
+ * Date: @DATE
  */
 (function( window, undefined ) {
 
+// Use the correct document accordingly with window argument (sandbox)
+var document = window.document;
